@@ -1,19 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2000 Waldo Bastian <bastian@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KBUILD_SERVICE_GROUP_FACTORY_H
@@ -33,7 +22,7 @@ public:
     /**
      * Create factory
      */
-    KBuildServiceGroupFactory(KSycoca *db);
+    explicit KBuildServiceGroupFactory(KSycoca *db);
 
     ~KBuildServiceGroupFactory() override;
 
